package soakafka;

import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.Producer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.common.serialization.StringSerializer;
import org.apache.kafka.common.serialization.StringDeserializer;

import java.util.Arrays;
import java.util.Date;
import java.util.Properties;

public class KafkaExample {
    private final String topic;
    private final Properties props;

    public KafkaExample(String brokers, String username, String password) {
        this.topic = "kafka_like";

        String jaasTemplate = "org.apache.kafka.common.security.scram.ScramLoginModule required username=\"%s\" password=\"%s\";";
        String jaasCfg = String.format(jaasTemplate, username, password);

        String serializer = StringSerializer.class.getName();
        String deserializer = StringDeserializer.class.getName();
        //Propriedades
        props = new Properties();
        props.put("bootstrap.servers", brokers);
        props.put("group.id", "kafka-hoshikawa");
        props.put("key.serializer", serializer);
        props.put("value.serializer", serializer);
        props.put("security.protocol", "SASL_SSL");
        props.put("sasl.mechanism", "PLAIN");
        props.put("sasl.jaas.config", jaasCfg);
        props.put("ssl.client.auth", "requested");
    }

    public String consume() {
        String ret = "";
        KafkaConsumer<String, String> consumer = new KafkaConsumer<>(props);
        consumer.subscribe(Arrays.asList(topic));

        while (true) {
          ConsumerRecords<String, String> records = consumer.poll(10);
          for (ConsumerRecord<String, String> record : records)
          {
            System.out.println(record.offset() + ": " + record.value());
            ret = ret + record.value();
          }
            if (ret != "")
              break;              
        }
      consumer.close();
        return ret;
    };

    public void produce(String message) {
        Thread one = new Thread() {
            public void run() {
                Producer<String, String> producer = new KafkaProducer<>(props);
                int i = 0;
                producer.send(new ProducerRecord<>(topic, Integer.toString(i), message));
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException e) {
                }
                i++;
                producer.flush();
                producer.close();
            }
        };
        one.start();
    }

    public static void main(String[] args) {
                /*
		String brokers = System.getenv("CLOUDKARAFKA_BROKERS");
		String username = System.getenv("CLOUDKARAFKA_USERNAME");
		String password = System.getenv("CLOUDKARAFKA_PASSWORD");
                */
                String brokers = "cell-1.streaming.us-ashburn-1.oci.oraclecloud.com:9092";
                String username = "hoshikawaoraclecloud/oracleidentitycloudservice/hoshikawa2@hotmail.com/ocid1.streampool.oc1.iad.amaaaaaaihuwreyagjtsqtsamegi4nerjxxwspkckiokrvoukgztajzakb5a";
                String password = "W(22}s.C[)Ya9Uc)#kLk";
		KafkaExample c = new KafkaExample(brokers, username, password);
        c.produce("teste");
        c.consume();
    }
}
